@@ -2,15 +2,10 @@ import datetime
 import pickle
 import unittest
 from decimal import Decimal
+from zoneinfo import ZoneInfo
 
 import parsedatetime
 
-try:
-    from zoneinfo import ZoneInfo
-except ImportError:
-    # Fallback for Python < 3.9
-    from backports.zoneinfo import ZoneInfo
-
 from agate.data_types import Boolean, Date, DateTime, Number, Text, TimeDelta
 from agate.exceptions import CastError
 
@@ -410,7 +405,7 @@ class TestDateTime(unittest.TestCase):
         # so we will catch any CastError that may arise from the conversion
         possible_values = (
             ('1994-03-01 12:30 오후', '2011-02-17 06:30 오전', None, '1984-01-05 06:30 오후', 'n/a'),
-            ('1994-03-01 12:30 PM', '2011-02-17 06:30 AM', None, '1984-01-05 06:30 PM', 'n/a'),
+            ('1994-03-01 12:30 AM', '2011-02-17 06:30 #오전', None, '1984-01-05 06:30 AM', 'n/a'),
         )
         valid = False
         exceptions = []
